# WISESIGHT

Wisesight is a Python library for consuming the wisesight socialistening api.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `wisesight`.

```bash
pip install wisesight
```

## Usage

```python
import wisesight

```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)
